@@ -1347,6 +1347,5 @@ class Supervision(CallbackInterface, metaclass=SuperclassDocstring):
 DEFAULT_CALLBACKS = [
     ProgressBarCallback(),
     PrintCallback(),
-    EarlyStoppingCallback(verbose=True),
-    Backup()
+    EarlyStoppingCallback(verbose=True)
 ]
